pub struct LoadingBin {
stack: TemplateChild<Stack>,
child_bin: TemplateChild<Bin>,
child: PhantomData<Option<Widget>>,
is_loading: PhantomData<bool>,
vhomogeneous: PhantomData<bool>,
}Fields
stack: TemplateChild<Stack>child_bin: TemplateChild<Bin>child: PhantomData<Option<Widget>>The child widget.
is_loading: PhantomData<bool>Whether this is showing the spinner.
vhomogeneous: PhantomData<bool>Whether this should keep the same height when showing the spinner or the content.
Implementations
Sourceimpl LoadingBin
impl LoadingBin
Sourcefn register_type()
fn register_type()
Registers the type only once.
Sourceimpl LoadingBin
impl LoadingBin
Sourcefn is_loading(&self) -> bool
fn is_loading(&self) -> bool
Whether this row is showing the spinner.
Sourcefn set_is_loading(&self, loading: bool)
fn set_is_loading(&self, loading: bool)
Set whether this row is showing the spinner.
Sourcefn vhomogeneous(&self) -> bool
fn vhomogeneous(&self) -> bool
Whether this should keep the same height when showing the spinner or the content.
Sourcefn set_vhomogeneous(&self, homogeneous: bool)
fn set_vhomogeneous(&self, homogeneous: bool)
Set whether this should keep the same height when showing the spinner or the content.